==> kbib_0.6.1.orig.tar.gz: kbib-0.6.1/kbib/kbibfinddlg.h <==
/***************************************************************************
                          kbibfinddlg.h  -  description
                             -------------------
    begin                : Sat Aug 9 2003
    copyright            : (C) 2003 by Thach Nguyen
    email                : thach@dragon.thach.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KBIBFINDDLG_H
#define KBIBFINDDLG_H

#include <qwidget.h>
#include <qcheckbox.h>
#include <kdialogbase.h>
#include <kcombobox.h>


//class KBibApp;

/**
  *@author Thach Nguyen
  */

class KBibFindDlg : public KDialogBase  {
   Q_OBJECT
public: 
	KBibFindDlg(QWidget* parent, const char *name=0);

  ~KBibFindDlg();
  /** No descriptions */
  void updateAttributeList();
  /** No descriptions */
  void slotFindNext();

private:

  KHistoryCombo* m_pattern;
  KComboBox* m_attributes;
  QCheckBox* m_caseSensitive;
//  QCheckBox* m_findBackwards;
//  QCheckBox* m_asRegExp;
//  QCheckBox* m_wholeWords;
  QCheckBox* m_fromBeginning;

  int startIndex;
  
public slots: // Public slots
  /** No descriptions */
  void slotPatternChanged(const QString& text_);
  /** No descriptions */
  void slotUser1();
};

#endif

==> kbib_0.6.5.orig.tar.gz: kbib-0.6.5/kbib/kbibfinddlg.h <==
/***************************************************************************
                          kbibfinddlg.h  -  description
                             -------------------
    begin                : Sat Aug 9 2003
    copyright            : (C) 2003 by Thach Nguyen
    email                : thach.nguyen@rmit.edu.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KBIBFINDDLG_H
#define KBIBFINDDLG_H

#include <qwidget.h>
#include <qcheckbox.h>
#include <kdialogbase.h>
#include <kcombobox.h>


//class KBibApp;

/**
  *@author Thach Nguyen
  */

class KBibFindDlg : public KDialogBase  {
   Q_OBJECT
public: 
	KBibFindDlg(QWidget* parent, const char *name=0);

  ~KBibFindDlg();
  /** No descriptions */
  void updateAttributeList();
  /** No descriptions */
  void slotFindNext();

private:

  KHistoryCombo* m_pattern;
  KComboBox* m_attributes;
  QCheckBox* m_caseSensitive;
//  QCheckBox* m_findBackwards;
//  QCheckBox* m_asRegExp;
//  QCheckBox* m_wholeWords;
  QCheckBox* m_fromBeginning;

  int startIndex;
  
public slots: // Public slots
  /** No descriptions */
  void slotPatternChanged(const QString& text_);
  /** No descriptions */
  void slotUser1();
};

#endif
